==> open-cluster-management-observability-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/CommonSpecFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.ResourceRequirementsBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CommonSpecFluentImpl<A extends CommonSpecFluent<A>> extends BaseFluent<A> implements CommonSpecFluent<A>{
  public CommonSpecFluentImpl() {
  }
  public CommonSpecFluentImpl(CommonSpec instance) {
    this.withReplicas(instance.getReplicas()); 
    this.withResources(instance.getResources()); 
  }
  private Integer replicas;
  private ResourceRequirementsBuilder resources;
  public Integer getReplicas() {
    return this.replicas;
  }
  public A withReplicas(Integer replicas) {
    this.replicas=replicas; return (A) this;
  }
  public Boolean hasReplicas() {
    return this.replicas != null;
  }
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceRequirements getResources() {
    return this.resources!=null ?this.resources.build():null;
  }
  public ResourceRequirements buildResources() {
    return this.resources!=null ?this.resources.build():null;
  }
  public A withResources(ResourceRequirements resources) {
    _visitables.get("resources").remove(this.resources);
    if (resources!=null){ this.resources= new ResourceRequirementsBuilder(resources); _visitables.get("resources").add(this.resources);} else { this.resources = null; _visitables.get("resources").remove(this.resources); } return (A) this;
  }
  public Boolean hasResources() {
    return this.resources != null;
  }
  public CommonSpecFluent.ResourcesNested<A> withNewResources() {
    return new CommonSpecFluentImpl.ResourcesNestedImpl();
  }
  public CommonSpecFluent.ResourcesNested<A> withNewResourcesLike(ResourceRequirements item) {
    return new CommonSpecFluentImpl.ResourcesNestedImpl(item);
  }
  public CommonSpecFluent.ResourcesNested<A> editResources() {
    return withNewResourcesLike(getResources());
  }
  public CommonSpecFluent.ResourcesNested<A> editOrNewResources() {
    return withNewResourcesLike(getResources() != null ? getResources(): new ResourceRequirementsBuilder().build());
  }
  public CommonSpecFluent.ResourcesNested<A> editOrNewResourcesLike(ResourceRequirements item) {
    return withNewResourcesLike(getResources() != null ? getResources(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CommonSpecFluentImpl that = (CommonSpecFluentImpl) o;
    if (replicas != null ? !replicas.equals(that.replicas) :that.replicas != null) return false;
    if (resources != null ? !resources.equals(that.resources) :that.resources != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(replicas,  resources,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (replicas != null) { sb.append("replicas:"); sb.append(replicas + ","); }
    if (resources != null) { sb.append("resources:"); sb.append(resources); }
    sb.append("}");
    return sb.toString();
  }
  class ResourcesNestedImpl<N> extends ResourceRequirementsFluentImpl<CommonSpecFluent.ResourcesNested<N>> implements CommonSpecFluent.ResourcesNested<N>,Nested<N>{
    ResourcesNestedImpl(ResourceRequirements item) {
      this.builder = new ResourceRequirementsBuilder(this, item);
    }
    ResourcesNestedImpl() {
      this.builder = new ResourceRequirementsBuilder(this);
    }
    ResourceRequirementsBuilder builder;
    public N and() {
      return (N) CommonSpecFluentImpl.this.withResources(builder.build());
    }
    public N endResources() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-observability-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/CommonSpecFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.ResourceRequirementsBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ResourceRequirementsFluentImpl;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CommonSpecFluentImpl<A extends CommonSpecFluent<A>> extends BaseFluent<A> implements CommonSpecFluent<A>{
  public CommonSpecFluentImpl() {
  }
  public CommonSpecFluentImpl(CommonSpec instance) {
    if (instance != null) {
      this.withReplicas(instance.getReplicas());
      this.withResources(instance.getResources());
    }
  }
  private Integer replicas;
  private ResourceRequirementsBuilder resources;
  public Integer getReplicas() {
    return this.replicas;
  }
  public A withReplicas(Integer replicas) {
    this.replicas=replicas; return (A) this;
  }
  public Boolean hasReplicas() {
    return this.replicas != null;
  }
  
  /**
   * This method has been deprecated, please use method buildResources instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceRequirements getResources() {
    return this.resources!=null ?this.resources.build():null;
  }
  public ResourceRequirements buildResources() {
    return this.resources!=null ?this.resources.build():null;
  }
  public A withResources(ResourceRequirements resources) {
    _visitables.get("resources").remove(this.resources);
    if (resources!=null){ this.resources= new ResourceRequirementsBuilder(resources); _visitables.get("resources").add(this.resources);} else { this.resources = null; _visitables.get("resources").remove(this.resources); } return (A) this;
  }
  public Boolean hasResources() {
    return this.resources != null;
  }
  public CommonSpecFluentImpl.ResourcesNested<A> withNewResources() {
    return new CommonSpecFluentImpl.ResourcesNestedImpl();
  }
  public CommonSpecFluentImpl.ResourcesNested<A> withNewResourcesLike(ResourceRequirements item) {
    return new CommonSpecFluentImpl.ResourcesNestedImpl(item);
  }
  public CommonSpecFluentImpl.ResourcesNested<A> editResources() {
    return withNewResourcesLike(getResources());
  }
  public CommonSpecFluentImpl.ResourcesNested<A> editOrNewResources() {
    return withNewResourcesLike(getResources() != null ? getResources(): new ResourceRequirementsBuilder().build());
  }
  public CommonSpecFluentImpl.ResourcesNested<A> editOrNewResourcesLike(ResourceRequirements item) {
    return withNewResourcesLike(getResources() != null ? getResources(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CommonSpecFluentImpl that = (CommonSpecFluentImpl) o;
    if (!java.util.Objects.equals(replicas, that.replicas)) return false;

    if (!java.util.Objects.equals(resources, that.resources)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(replicas,  resources,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (replicas != null) { sb.append("replicas:"); sb.append(replicas + ","); }
    if (resources != null) { sb.append("resources:"); sb.append(resources); }
    sb.append("}");
    return sb.toString();
  }
  class ResourcesNestedImpl<N> extends ResourceRequirementsFluentImpl<CommonSpecFluentImpl.ResourcesNested<N>> implements CommonSpecFluentImpl.ResourcesNested<N>,Nested<N>{
    ResourcesNestedImpl(ResourceRequirements item) {
      this.builder = new ResourceRequirementsBuilder(this, item);
    }
    ResourcesNestedImpl() {
      this.builder = new ResourceRequirementsBuilder(this);
    }
    ResourceRequirementsBuilder builder;
    public N and() {
      return (N) CommonSpecFluentImpl.this.withResources(builder.build());
    }
    public N endResources() {
      return and();
    }
    
  }
  
}
